@@ -14,6 +14,7 @@ try:
     #from render_text_input import text_input
     #from render_code_input import code_input
     #from render_file_upload import file_upload
+    from social_media import share
 except:
     ### The main function to be used to read the files
     from .file_reader import set_book_config
@@ -25,6 +26,6 @@ except:
     #from .render_text_input import text_input
     #from .render_code_input import code_input
     #from .render_file_upload import file_upload
-
+    from .social_media import share
 
 
